@@ -18,10 +18,9 @@ type DataHeaders = (
 );
 
 /// Lit les deux premières lignes du fichier d'entrée.
-fn read_headers(s: &Path) -> Result<DataHeaders, io::Error> {
+fn read_headers(f: File) -> Result<DataHeaders, io::Error> {
     let mut candidates = Vec::new();
 
-    let f = File::open(s).expect("Fichier d'entrée manquant.");
     let mut lines = io::BufReader::new(f).lines();
 
     let line0 = lines.next().expect("Le fichier d'entrée semble vide.")?;
@@ -101,8 +100,12 @@ fn read_data(data_headers: DataHeaders) -> Result<Data, io::Error> {
 
 /// Lit dans le fichier d'entrée les statuts des questions, et les scores et
 /// les réponses des candidats.
-pub fn read(filename: &Path) -> Result<Data, io::Error> {
-    let data_headers = read_headers(filename)?;
+pub fn read(path: &str, filename: &str) -> Result<Data, io::Error> {
+    let f = File::open(&Path::new(path).join(format!("{}.tsv", filename))).unwrap_or_else(|_| {
+        File::open(&Path::new(path).join(format!("{}.csv", filename)))
+            .expect(&format!("Fichier d'entrée manquant : {}", filename))
+    });
+    let data_headers = read_headers(f)?;
     read_data(data_headers)
 }
 
@@ -211,8 +214,8 @@ pub fn write(sols: &[Vec<Axis>], f: &Path) -> Result<(), io::Error> {
 }
 
 /// Lit le fichier d'heuristiques, en tire les deltas et la stratégie choisis.
-pub fn read_heuristics(filename: &Path) -> Result<Heuristics, io::Error> {
-    let f = File::open(filename).expect("Fichier d'heuristiques manquant ?");
+pub fn read_heuristics(path: &Path, filename: &Path) -> Result<Heuristics, io::Error> {
+    let f = File::open(path.join(filename)).expect("Fichier d'heuristiques manquant ?");
     let mut lines = io::BufReader::new(f)
         .lines()
         .map(|l| l.expect("Erreur dans les lignes du fichier d'heuristiques"))
@@ -233,7 +236,11 @@ pub fn read_heuristics(filename: &Path) -> Result<Heuristics, io::Error> {
             }
 
             let b: &[_] = &['[', ']'];
-            let field: Vec<_> = parts[1].trim_matches(b).split(',').map(|s| s.trim()).collect();
+            let field: Vec<_> = parts[1]
+                .trim_matches(b)
+                .split(',')
+                .map(|s| s.trim())
+                .collect();
             for v in field {
                 heuristics.strategy.push(
                     v.parse()
@@ -264,12 +271,12 @@ mod tests {
 
     #[test]
     fn read_total_works() {
-        match read_headers(&Path::new("tests").join(Path::new("DP10.csv"))) {
+        match read_headers(File::open(&Path::new("tests").join(&Path::new("DP10.csv"))).unwrap()) {
             Err(a) => panic!("{:?}", a),
             Ok((_, total, _, _)) => assert_eq!(total, Some(18)),
         }
 
-        match read_headers(&Path::new("tests").join(Path::new("DP1.csv"))) {
+        match read_headers(File::open(&Path::new("tests").join(&Path::new("DP1.csv"))).unwrap()) {
             Err(a) => panic!("{:?}", a),
             Ok((_, total, _, _)) => assert_eq!(total, None),
         }
@@ -277,7 +284,7 @@ mod tests {
 
     #[test]
     fn read_headers_works() {
-        match read_headers(&Path::new("tests").join(Path::new("DP1.csv"))) {
+        match read_headers(File::open(&Path::new("tests").join(&Path::new("DP1.csv"))).unwrap()) {
             Err(a) => panic!("{:?}", a),
             Ok((_, _, candidates, _)) => {
                 assert_eq!(candidates.len(), 14);
@@ -299,7 +306,7 @@ mod tests {
 
     #[test]
     fn read_with_coeffs_works() {
-        match read(&Path::new("tests").join(Path::new("DP10.csv"))) {
+        match read(&"tests", &"DP10") {
             Err(a) => panic!("{:?}", a),
             Ok(d) => {
                 assert_eq!(d.candidates[0].actual_error, 23);
@@ -311,7 +318,7 @@ mod tests {
 
     #[test]
     fn read_works() {
-        match read(&Path::new("tests").join(Path::new("DP1.csv"))) {
+        match read(&"tests", &"DP1") {
             Err(a) => panic!("{:?}", a),
             Ok(d) => {
                 assert_eq!(d.statuses.len(), 15);
@@ -329,7 +336,7 @@ mod tests {
             }
         }
 
-        match read(&Path::new("tests").join(Path::new("DP14.csv"))) {
+        match read(&"tests", &"DP14") {
             Err(a) => panic!("{:?}", a),
             Ok(d) => {
                 assert_eq!(d.statuses.len(), 15);
@@ -341,14 +348,17 @@ mod tests {
 
     #[test]
     fn read_heuristics_works() {
-        match read_heuristics(&Path::new("tests").join(Path::new("heuristiques.toml"))) {
+        match read_heuristics(&Path::new("tests"), &Path::new("heuristiques.toml")) {
             Err(a) => panic!("{:?}", a),
             Ok(h) => {
                 assert_eq!(h.strategy, vec![0]);
             }
         }
-        
-        match read_heuristics(&Path::new("tests").join(Path::new("heuristiques_enrichies.toml"))) {
+
+        match read_heuristics(
+            &Path::new("tests"),
+            &Path::new("heuristiques_enrichies.toml"),
+        ) {
             Err(a) => panic!("{:?}", a),
             Ok(h) => {
                 assert_eq!(h.strategy, vec![0, 1, 5]);
